@@ -195,7 +195,8 @@ class ProjectManager(object):
                       'times': root / 'times',
                       'hdf5_times': root / 'hdf5_times',
                       'ai_models': root / 'ai_models',
-                      'debug': root / 'debug'}
+                      'debug': root / 'debug',
+                      'index': root / 'index'}
 
         self.paths = AttribDict(self.paths)
 
@@ -227,7 +228,7 @@ class ProjectManager(object):
 
         if not self.files.settings.is_file():
             settings_template = settings_path / \
-                                    '../settings/settings_template.toml'
+                                    'settings/settings_template.toml'
 
             shutil.copyfile(settings_template, self.files.settings)
 
