@@ -22,6 +22,7 @@ import docker
 from ..tomography import data as estuaire_data
 import os
 import pickle
+from pathlib import Path
 
 __cpu_count__ = cpu_count()
 
@@ -430,8 +431,7 @@ class Tomography(ProjectManager):
         self.paths.current_epoch = self.paths.tomography / \
                                        f'epoch_{self.epoch}'
 
-        if not self.paths.current_epoch.exists():
-            self.paths.current_epoch.mkdir(parents=True, exist_ok=True)
+        self.paths.current_epoch.mkdir(parents=True, exist_ok=True)
 
     @property
     def travel_time_table_path(self):
@@ -449,11 +449,16 @@ class Tomography(ProjectManager):
 
     @property
     def event_table_file(self):
-        return self.paths.current_epoch / 'event_table.pickle'
+        event_table_file = self.paths.current_epoch / 'event_table.pickle'
+        event_table_file.parent.mkdir(parents=True, exist_ok=True)
+        return event_table_file
+
 
     @property
     def site_table_file(self):
-        return self.paths.current_epoch / 'site_table.pickle'
+        site_table_file = self.paths.current_epoch / 'site_table.pickle'
+        site_table_file.parent.mkdir(parents=True, exist_ok=True)
+        return site_table_file
 
     @property
     def path_velocities(self):
@@ -464,6 +469,10 @@ class Tomography(ProjectManager):
     def velocity_file(self, phase):
         return self.path_velocities / f'{phase}_velocity.pickle'
 
+    @property
+    def estuaire_path_prefix(self):
+        return Path('/tmp')
+
     @property
     def travel_time_grids_path(self):
         path_travel_time_grids = self.paths.current_epoch / 'travel_time_grids'
@@ -517,9 +526,12 @@ class Tomography(ProjectManager):
 
         ttt = np.array(ttt, dtype=estuaire_data.tt_dtype)
 
+        event_table_file = self.estuaire_path_prefix / self.event_table_file
+        site_table_file = self.estuaire_path_prefix / self.site_table_file
+
         tt_table = estuaire_data.EKTTTable(ttt, site_id,
-                                           evnfile=self.event_table_file,
-                                           stafile=self.site_table_file)
+                                           evnfile=event_table_file,
+                                           stafile=site_table_file)
 
         return tt_table
 
@@ -714,11 +726,26 @@ class Tomography(ProjectManager):
 
     def __write_velocity_grids__(self):
         with open(self.velocity_file(Phase('P')), 'wb') as p_velocity_file:
-            pickle.dump(self.p_velocity, p_velocity_file)
+
+            data = self.p_velocity.data
+            spacing = self.p_velocity.spacing[0]
+            origin = self.p_velocity.origin
+
+            p_velocity = estuaire_data.EKImageData(data, spacing=spacing,
+                                                   origin=origin)
+
+            pickle.dump(p_velocity, p_velocity_file)
             logger.info(f'writing the p velocity file ({p_velocity_file})')
 
         with open(self.velocity_file(Phase('S')), 'wb') as s_velocity_file:
-            pickle.dump(self.s_velocity, s_velocity_file)
+            data = self.p_velocity.data
+            spacing = self.p_velocity.spacing[0]
+            origin = self.p_velocity.origin
+
+            s_velocity = estuaire_data.EKImageData(data, spacing=spacing,
+                                                   origin=origin)
+
+            pickle.dump(s_velocity, s_velocity_file)
             logger.info(f'writing the s velocity file ({s_velocity_file})')
 
     def __write_travel_time_grids__(self):
@@ -726,8 +753,16 @@ class Tomography(ProjectManager):
             phase = Phase(travel_time_grid.phase)
             site_name = travel_time_grid.seed_label
             file_name = self.travel_time_grid_file(site_name, phase)
+
+            data = travel_time_grid.data
+            spacing = travel_time_grid.spacing[0]
+            origin = travel_time_grid.origin
+
+            grid = estuaire_data.EKImageData(data, spacing=spacing,
+                                             origin=origin)
+
             with open(file_name, 'wb') as output_file:
-                pickle.dump(travel_time_grid, output_file)
+                pickle.dump(grid, output_file)
 
             logger.info(f'writing the travel time grid for site {site_name} '
                         f'({file_name}')
@@ -741,20 +776,24 @@ class Tomography(ProjectManager):
 
     def run_sensitivity(self):
 
-        docker_volume = {os.getcwd(): {'bind': '/tmp/', 'mode': 'rw'}}
+        docker_volume = {os.getcwd(): {'bind': str(self.estuaire_path_prefix),
+                                       'mode': 'rw'}}
 
         self.paths.current_epoch / 'sensitivity'
         for site_name in self.travel_times.seed_labels:
             for phase in Phase:
+                sensitivity_file = self.estuaire_path_prefix / \
+                                   self.sensitivity_file(site_name, phase)
+                travel_time_grid_file = self.estuaire_path_prefix / \
+                    self.travel_time_grid_file(site_name, phase)
+                travel_time_table_file = self.estuaire_path_prefix / \
+                    self.travel_time_table_file(site_name, phase)
+
                 cmd = f'sensitivity ' \
-                      f'--output ' \
-                      f'/tmp/{self.sensitivity_file(site_name, phase)} ' \
-                      f'--arrival ' \
-                      f'/tmp/{self.travel_time_grid_file(site_name, phase)} ' \
+                      f'--output {sensitivity_file} ' \
+                      f'--arrival {travel_time_grid_file} ' \
                       f'--velocity /tmp/{self.velocity_file(phase)} ' \
-                      f'--traveltime ' \
-                      f'/tmp/' \
-                      f'{self.travel_time_table_file(site_name, phase)} ' \
+                      f'--traveltime {travel_time_table_file} ' \
                       f'--grid_id {10}'
                 self.docker_client.containers.run('jpmercier/estuaire', cmd,
                                                   volumes=docker_volume,
